package SOCC::ServiceResult;

use strict;
use warnings;
use English;
use POSIX ('uname');


our $VERSION = '0.01';


require Exporter;
our @ISA = ('Exporter');
our @EXPORT_OK = ('%STATUS_TO_RETURN_CODE', '@RETURN_CODE_TO_STATUS');



our %STATUS_TO_RETURN_CODE = (
	'OK'=>0,
	'WARNING'=>1,
	'CRITICAL'=>2,
	'UNKNOWN'=>3,
	'DEPENDENT'=>4,
);



our @RETURN_CODE_TO_STATUS = (
	'OK',
	'WARNING',
	'CRITICAL',
	'UNKNOWN',
	'DEPENDENT',
);





{
	my $idx = 0;
	use constant TIME_T => $idx++;
	use constant HOST_NAME => $idx++;
	use constant SERVICE_DESCR => $idx++;
	use constant RETURN_CODE => $idx++;
	use constant OUTPUT => $idx++;
}



sub new {
	my $class = shift(@_);
	my %args = (time_t => time(), host_name => (POSIX::uname())[1], @_);
	if (! defined $args{status} && ! defined $args{return_code}) {
		$args{return_code} = -1;
	}
	
	my $self = bless([], $class);
	foreach my $arg_key (keys %args) {
		$self->$arg_key($args{$arg_key});
	}
	return $self;
}



sub time_t {
	my $self = shift(@_);
	my $newval = shift(@_);
	if (defined $newval) {
		$self->[TIME_T] = $newval;
	}
	return $self->[TIME_T];
}



sub host_name {
	my $self = shift(@_);
	my $newval = shift(@_);
	if (defined $newval) {
		$self->[HOST_NAME] = $newval;
	}
	return $self->[HOST_NAME];
}



sub return_code {
	my ($self, $newval) = @_;
	
	if (defined $newval) {
		if (! defined $RETURN_CODE_TO_STATUS[$newval]) {
			die "Unexpected Error";
		}
		$self->[RETURN_CODE] = $newval;
	}
	
	return $self->[RETURN_CODE];
}



sub status {
	my ($self, $newval) = @_;
	my $status;
	
	if (defined $newval) {
		if (defined $STATUS_TO_RETURN_CODE{uc $newval}) {
			$self->[RETURN_CODE] = $STATUS_TO_RETURN_CODE{uc $newval};
		} else {
			die "Unexpected Error";
		}
	}
	
	if (defined $self->[RETURN_CODE]) {
		$status = $RETURN_CODE_TO_STATUS[$self->[RETURN_CODE]];
	}
	
	return $status;
}



sub service_descr {
	my $self = shift(@_);
	my $newval = shift(@_);
	if (defined $newval) {
		$self->[SERVICE_DESCR] = $newval;
	}
	return $self->[SERVICE_DESCR];
}



sub output {
	my $self = shift(@_);
	my $newval = shift(@_);
	if (defined $newval) {
		$self->[OUTPUT] = $newval;
	}
	return $self->[OUTPUT];
}


1;
