#!/usr/bin/perl


use strict;
use warnings;
use English;
use Test::More tests => 11;


BEGIN {use_ok('SOCC::ServiceResult');}


{
	# With no defaults.
	my $event = SOCC::ServiceResult->new(
		time_t => 11111111,
		host_name => 'somehost',
		service_descr => 'Some Service',
		return_code => 0,
		output => 'Service is OK');
	ok ($event->time_t() == 11111111 &&
		$event->host_name() eq 'somehost' &&
		$event->service_descr() eq 'Some Service' &&
		$event->return_code() == 0 &&
		$event->output() eq 'Service is OK');
}


{
	# With all defaults
	my $time = time();
	my $event = SOCC::ServiceResult->new(
		service_descr => 'Some Service',
		output => 'Unknown');
	ok ($event->time_t() >= $time && # Defaults to curr time.
		defined $event->host_name() && # Defaults to hostname.
		$event->service_descr() eq 'Some Service' && 
		$event->return_code() == -1 && # Defaults to UNKNOWN.
		$event->output() eq 'Unknown');
}


{
	# Demonstrate status()
	my $event = SOCC::ServiceResult->new(
		time_t => 11111111,
		host_name => 'somehost',
		service_descr => 'Some Service',
		output => 'Service Output');
	
	$event->return_code(0);
	ok($event->status() eq 'OK');
	
	$event->return_code(1);
	ok($event->status() eq 'WARNING');
	
	$event->return_code(2);
	ok($event->status() eq 'CRITICAL');
	
	$event->return_code(3);
	ok($event->status() eq 'UNKNOWN');
	
	# Note that input to status is case insensitive.
	$event->status('Ok');
	ok($event->return_code() == 0);
	
	$event->status('warNinG');
	ok($event->return_code() == 1);
	
	$event->status('CRiTIcAL');
	ok($event->return_code() == 2);
	
	$event->status('unkNoWn');
	ok($event->return_code() == 3);
}
